{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li class="active">{{ title }}</li>
			</ul>{% endblock %}

{% block content %}
					<p>{% trans "Something's wrong with your database installation. Make sure the appropriate database tables have been created, and make sure the database is readable by the appropriate user." %}</p>
{% endblock %}
