{% extends "admin/base_site.html" %}{% load admin_list i18n admin_static yawdadmin_tags yawdadmin_filters %}{% load url from future %}

{% block extrastyle %}{{ block.super }}{% if not actions_on_top and not actions_on_bottom %}
		<style>
			#changelist table thead th:first-child { width: inherit; }
		</style>{% endif %}{% endblock %}

{% block extrahead %}{{ block.super }}{% if cl.formset or action_form %}{% url 'admin:jsi18n' as jsi18nurl %}
		<script src="{{ jsi18nurl|default:'../../jsi18n/' }}"></script>{% endif %}{% if is_popup %}
		<script>
			var opener = parent;
		</script>
		{% endif %}{% if action_form %}{% if actions_on_top or actions_on_bottom %}
		<script type="text/javascript">
			(function($) {
				$(document).ready(function($) {
					$("tr input.action-select").actions();
				});
			})(yawdadmin.jQuery);
		</script>{% endif %}{% endif %}
		{% clean_media media %}{% endblock %}

{% block bodyclass %}change-list{% endblock %}

{% block breadcrumbs %}{% if not is_popup %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li><a href="{% url 'admin:app_list' app_label=cl.opts.app_label %}">{% with app_title=app_label|app_title|escape %}{{ app_title.title }}{% endwith %}</a> <span class="divider">/</span></li>
				<li class="active">{{ cl.opts.verbose_name_plural|capfirst }}</li>
			</ul>{% endif %}{% endblock %}

{% block object-tools %}
			<div class="row-fluid nav">{% block object-tools-items %}{% if has_add_permission %}
				<div class="span2">
					<a href="add/{% if is_popup %}?_popup=1{% endif %}" class="big-button">
						<i class="add-item"></i> {% blocktrans with cl.opts.verbose_name as name %}Add {{ name }}{% endblocktrans %}
					</a>
				</div>{% endif %}{% endblock %}
			</div>{% endblock %}

{% block main-struct %}
			<div class="row-fluid show-grid">
				<div class="span{% if cl.has_filters %}9{% else %}12{% endif %}">
					<div id="content-main">{% if cl.formset.errors %}
						<p class="alert alert-error close">
							{% blocktrans count cl.formset.errors|length as counter %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
						</p>
						{{ cl.formset.non_form_errors }}{% endif %}
						<div class="module{% if cl.has_filters %} filter{% endif %}">
							<form id="changelist-form" action="" method="post"{% if cl.formset.is_multipart %} enctype="multipart/form-data"{% endif %}>{% csrf_token %}{% if cl.formset %}
								<div>{{ cl.formset.management_form }}</div>{% endif %}{% block result_list %}
								<div id="changelist-top" class="row-fluid grey-degrade">{% if action_form and actions_on_top and cl.full_result_count %}
									{% admin_actions %}{% else %}
									<div class="span6"></div>{% endif %}
								</div>
								{% block date_hierarchy %}{% date_hierarchy cl %}{% endblock %}
								{% result_list cl %}{% if action_form and actions_on_bottom and cl.full_result_count %}
								{% admin_actions %}{% endif %}{% endblock %}{% block pagination %}
								{% pagination cl %}{% endblock %}
							</form>
							{% block search %}{% search_form cl %}{% endblock %}
						</div>
					</div>
				</div>{% if cl.has_filters %}
				<div class="span3">
					<div class="changelist-filter well well-open clearfix">
						<h3 class="filter-title">{% trans 'Filter' %}</h3>{% for spec in cl.filter_specs %}
						{% admin_list_filter cl spec %}{% endfor %}
					</div>
				</div>{% endif %}
			</div>{% endblock %}