body {
	background-color: #fff;
}

.container-fluid {
	max-width: 1400px !important;
	margin: auto;
}

h1, h2, h3, h4, h5, h6 {
	font-family: 'Open Sans Condensed', Arial, sans-serif;
}

th {
	font-weight: normal !important;
}

thead th {
	font-weight: bold !important;
}

input[type="checkbox"] {
	margin: -2px 0 0 0 !important;
}

.help-inline ul, .alert-error ul, .alert-success ul, .messagelist {
	list-style: none;
	padding: 0;
	margin: 0;
}

.required {
	font-weight: bold;
}

.add-bottom {
	margin-bottom: 20px;
}

.add-top {
	margin-top: 20px;
}

.alert-error a {
	color: #892A28;
	text-decoration: underline;
}

.alert-error a:hover {
	color: #a94A48;
}

.navbar .brand {
	padding-left: 30px;
	font: 300 16px 'Open Sans Condensed', sans-serif;
}

.navbar .brand i {
	margin-top: 5px;
}

.navbar-fixed-top .nav-collapse i {
	opacity: 0.6;
}

.navbar-fixed-top .nav-collapse li:hover i {
	opacity: 1;
}

.main {
	padding-top: 60px;
}

@media (max-width: 979px) {
	.main {
		padding-top: 0;
	}
}

.table-rounded {
	border: 1px solid #DDD;
	border-collapse: separate;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

.navbar-blue {
	color: #ddd;
}

.navbar-blue .brand, .navbar-inverse .nav > li > a {
	color: #eee;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.5);
}

.navbar-blue .nav > li > a {
	color: #fff;
	text-shadow: 0 1px 0 rgba(0, 0, 0, 0.5);
	opacity: .9;
}

.navbar-blue .btn-navbar:hover, .navbar-blue .btn-navbar:active, .navbar-blue .btn-navbar.active, .navbar-blue  .btn-navbar.disabled, .navbar-blue  .btn-navbar[disabled] {
	color: white;
	background-color: #005E9D;
}

.navbar-blue .nav li.dropdown.open > .dropdown-toggle, .navbar-blue .nav li.dropdown.active > .dropdown-toggle, .navbar-blue .nav li.dropdown.open.active > .dropdown-toggle {
	background-color: #005E9D;
}

.navbar-blue .nav > li:hover > a, .navbar-blue.navbar-fixed-top .btn-navbar:hover span {
	opacity: 1;
}

.navbar-blue .divider-vertical {
	border-left-color: #2078A1;
	border-right-color: #3497C2;
}

.navbar-blue.navbar-fixed-top .nav-collapse i, .navbar-blue.navbar-fixed-top .btn-navbar span {
	opacity: .9;
}

.navbar-blue .nav li.dropdown > .dropdown-toggle .caret {
	border-top-color: #fff;
	border-bottom-color: #fff;
	opacity: .9;
}

.navbar-blue .nav li.dropdown:hover > .dropdown-toggle .caret {
	border-top-color: #fff;
	border-bottom-color: #fff;
	opacity: 1;
}

@media (max-width: 979px) {
	.navbar-blue .nav-collapse .nav > li > a:hover, .navbar-blue .nav-collapse .dropdown-menu a:hover {
		background-color: #005E9D !important;
	}
	
	.nav-collapse .nav > li > a, .nav-collapse .dropdown-menu a {
		color: #eee;
	}
}

.navbar-blue .btn-navbar {
	margin-top: 3px;
}

.navbar-blue .btn-navbar {
	color: white;
	text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
	background-color: #0088cc;
	background-image: -moz-linear-gradient(top, #0088cc, #005E9D);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#005E9D));
	background-image: -webkit-linear-gradient(top, #0088cc, #005E9D);
	background-image: -o-linear-gradient(top, #0088cc, #005E9D);
	background-image: linear-gradient(to bottom, #0088cc, #005E9D);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0088cc', endColorstr='#ff005E9D', GradientType=0);
	border-color: #0077aa;
	filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
}

.navbar-blue .navbar-inner, .blue-degrade {
	background: #0088cc;
	background: -moz-linear-gradient(top, #0088cc 0%, #005E9D 100%);
	background: -webkit-gradient(linear, 0 0, 0 100%, from(#0088cc), to(#005E9D));
	background: -webkit-linear-gradient(top, #0088cc 0%,#005E9D 100%);
	background: -o-linear-gradient(top, #0088cc 0%,#005E9D 100%);
	background: -ms-linear-gradient(top, #0088cc 0%,#005E9D 100%);
	background: linear-gradient(top, #0088cc 0%,#005E9D 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#0088cc', endColorstr='#005E9D',GradientType=0 );
	color: #fff;
	webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1),0 1px 10px rgba(0, 0, 0, 0.1);
	-moz-box-shadow: inset 0 -1px 0 rgba(0,0,0,0.1),0 1px 10px rgba(0,0,0,0.1);
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1),0 1px 10px rgba(0, 0, 0, 0.1);
}

.grey-degrade, .breadcrumb, .tabular.inline-related .add-row td {
	background-color: #FAFAFA;
	background-image: -moz-linear-gradient(top, white, #F2F2F2);
	background-image: -webkit-gradient(linear, 0 0, 0 100%, from(white), to(#F2F2F2));
	background-image: -webkit-linear-gradient(top, white, #F2F2F2);
	background-image: -o-linear-gradient(top, white, #F2F2F2);
	background-image: linear-gradient(to bottom, white, #F2F2F2);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#FFFFFF', endColorstr='#F2F2F2',GradientType=0 );
	border: 1px solid #e4e4e4;
}

.breadcrumb {
	font-size: 13px;
}

.light-blue-degrade {
	background: #50AEDD;
	background: -moz-linear-gradient(top, #50AEDD 0%, #0088cc 100%);
	background: -webkit-gradient(linear, 0 0, 0 100%, from(#50AEDD), to(#0088cc));
	background: -webkit-linear-gradient(top, #50AEDD 0%,#0088cc 100%);
	background: -o-linear-gradient(top, #50AEDD 0%,#0088cc 100%);
	background: -ms-linear-gradient(top, #50AEDD 0%,#0088cc 100%);
	background: linear-gradient(top, #50AEDD 0%,#0088cc 100%);
	filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#509ECD', endColorstr='#0088cc',GradientType=0 );
	color: #fff;
	webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1),0 1px 10px rgba(0, 0, 0, 0.1);
	-moz-box-shadow: inset 0 -1px 0 rgba(0,0,0,0.1),0 1px 10px rgba(0,0,0,0.1);
	box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.1),0 1px 10px rgba(0, 0, 0, 0.1);
}

.light-blue-degrade a {
	color: #ddd;
	text-decoration: underline;
}

.light-blue-degrade a:hover {
	color: #fff;	
}

.clearfix {
	clear: both;
}

.well-open {
	background-color: #fff;
	-webkit-box-shadow: none !important;
	-moz-box-shadow: none !important;
	box-shadow: none !important;
	padding-top: 5px;
}

.well-open h3 {
	background-color: #f5f5f5;
	text-align: center;
}

/* OBJECT TOOLS ICONS */

.add-item {
	background: url('../img/add-item.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.loading-item {
	background: url('../img/ajax-loader.gif') 4px 4px no-repeat transparent;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.processing-item {
	background: url('../img/processing.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.reload-item {
	background: url('../img/reload.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.history-item {
	background: url('../img/database.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.fancy-globe-item {
	background: url('../img/fancy-globe.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.globe-item {
	background: url('../img/globe.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.preview-item {
	background: url('../img/lookup.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.configuration-item {
	background: url('../img/configuration.png') 0px 0px no-repeat;
	width: 32px;
	height: 32px;
	display: block;
	margin: auto;
}

.big-button {
	text-align: center;
	border: 1px solid #e4e4e4;
	border-collapse: separate;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	margin-bottom: 10px;
	display: block;
	background: #F9F9F9;
	background: -moz-linear-gradient(top, #F9F9F9 0%, #EFEFEF 100%);
	background: -webkit-gradient(linear, 0 0, 0 100%, from(#F9F9F9), to(#EFEFEF));
	background: -webkit-linear-gradient(top, #F9F9F9 0%,#EFEFEF 100%);
	background: -o-linear-gradient(top, #F9F9F9 0%,#EFEFEF 100%);
	background: -ms-linear-gradient(top, #F9F9F9 0%,#EFEFEF 100%);
	background: linear-gradient(top, #F9F9F9 0%,#EFEFEF 100%);
	progid:DXImageTransform.Microsoft.gradient( startColorstr='#f9f9f9', endColorstr='#efefef',GradientType=0 );
}

.big-button:hover {
	background: #F9F9F9;
	background: -moz-linear-gradient(top, #efefef 0%, #f9f9f9 100%);
	background: background: -webkit-gradient(linear, 0 0, 0 100%, from(#efefef), to(#f9f9f9));
	background: -webkit-linear-gradient(top, #efefef 0%,#F9F9F9 100%);
	background: -o-linear-gradient(top, #efefef 0%,#F9F9F9 100%);
	background: -ms-linear-gradient(top, #efefef 0%,#F9F9F9 100%);
	background: linear-gradient(top, #efefef 0%,#F9F9F9 100%);
	progid:DXImageTransform.Microsoft.gradient( startColorstr='#efefef', endColorstr='#F9F9F9',GradientType=0 );
	text-decoration: None;
	color: #08c;
}

/*  END ICONS */

#changelist-top {
	margin-bottom: 5px;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
}

.actions, .toolbar {
	padding: 10px;
}

select[name="action"] {
	margin-bottom: 0;
}

.small {
	font-size: 13px;
}

ul.toplinks {
	list-style: none;
}

ul.toplinks li {
	float: left;
	padding: 5px;
}

.help:hover {
	cursor: pointer;
	opacity: 1;
}

.help-tooltip {
	margin: 3px 0 0 2px;
	opacity: .9;
}

.field {
	padding: 4px;
	margin: 1px;
}

.color-form.row-fluid {
	background-color: #f9f9f9;
	margin-bottom: 1px;
	line-height: 30px;
}

.color-form.row-fluid.row2 {
	background-color: #fdfdfd;
}

.form-horizontal .color-form .control-group {
	margin-bottom: 0;
}

.form-horizontal fieldset {
	border-bottom: 1px solid #EEE;
}

.submits {
	margin: 40px 0 0 0;
}

.field h2 {
	font-size: 16px;
}

.pointer {
	cursor: pointer;
}

.h2-icon {
	margin-top: 12px;
}

.add-another:hover {
	text-decoration: none;
}

.lang-switcher {
	padding: 8px 15px 8px !important;
}

.log-link {
	display: inline-block !important;
	padding: 4px 5px !important;
	margin: 0 -4px !important;
}

.mini {
	font-size: 9px;
}

.quiet, a.quiet:link, a.quiet:visited {
	color: #999 !important;
	font-weight: normal !important;
}

.filter-title {
	font-size: 20px;
	margin: 4px 0;
}

.paginator {
	padding: 5px;
	text-shadow: 0 1px 0 #eee;
	color: #666;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

.breadcrumb li:first-child i {
	margin-top: 0px;
}

/*.breadcrumb .active {
	color: #fff;
}

.breadcrumb a {
	color: #fff;
}

.breadcrumb li {
	text-shadow: 0 1px 0 #666;
}*/

#chart_div {
	height: 250px;
}

.analytics-sum-wrapper {
	border: 0;
	border-bottom: 1px solid #eee;
}

.analytics-sum {
	padding: 10px 0 5px 0;
	text-align: center;
}

/* Elfinder overrides to remove bootstrap styling */

table.elfinder-info-tb {
	border-spacing: 2px;
	border-color: gray;
	line-height: normal;
}

table.elfinder-info-tb tr {
	border-bottom: 1px solid #e3e3e3;
}

.elfinder-info-title {
	line-height: normal;
}

/* Form field classes */

.tinymce {
	width: 80%;
}

.textarea-medium {
	width: 50%;
	height: 80px;
}

.textarea-full {
	width: 98%;
	padding: 1% !important;
	height: 400px;
}

.sortoptions {
	display: inline-block;
	float: right;
}

.sortoptions a:hover {
	text-decoration: none;
}

.sortpriority {
	font-size: .9em;
}

/* Original widget styling */

a.related-lookup:hover {
	text-decoration: none; 
}

div#id_password {
	display: inline;
}

.selector-available, .selector-chosen {
	float: left;
	width: 45%;
	text-align: center;
	margin-bottom: 5px;
}

.selector-available {
	margin-left: 1%;
}

.selector-available input, .selector-chosen input {
	width: 88% !important;
}

.selector-available select, .selector-chosen select {
	width: 99%;
	height: 17.2em;
}

.selector {
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	background-color: #ddd;
	overflow: auto;
}

.selector h2 {
	line-height: 30px;
	background-color: #08c;
	color:  #eee;
	-webkit-border-radius: 3px;
	-moz-border-radius: 3px;
	border-radius: 3px;
}

.selector ul.selector-chooser {
	float: left;
	width: 6%;
	height: 50px;
	background: #08c;
	margin: 11em 1% 0 1%;
	padding: 10px 0;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	border: 1px solid #06c;
}

@media (max-width: 455px) {
	.selector ul.selector-chooser {
		margin-top: 5px !important;
		margin-left: 40%;
	}
}

.selector-chooser li {
    margin: 0;
    padding: 5px;
    padding-left: 40%;
    list-style-type: none;
}

.selector-add, .selector-remove {
    width: 16px;
    height: 16px;
    display: block;
    text-indent: -3000px;
    overflow: hidden;
}

.calendarbox, .clockbox {
	background-color: #ddd;
	-webkit-border-radius: 6px;
	-moz-border-radius: 6px;
	border-radius: 6px;
	padding: 5px;
}

.calendarnav-previous {
	display: block;
	position: absolute;
	top: 8px;
	left: 10px;
	color: #fff;
	font-weight: bold;
}

.calendarnav-next {
	display: block;
	position: absolute;
	top: 8px;
	right: 10px;
	color: #fff;
	font-weight: bold;
}

.calendarnav-next:hover, .calendarnav-previous:hover {
	text-decoration: none;
	color: #eee;
}  

.calendar table {
	margin: auto;
}

.calendar table caption {
	background-color: #08c;
	color: #fff;
	padding: 3px 0;
	font-weight: bold;
}

.clockbox h2 {
	background-color: #08c;
	color: #fff;
	margin-top: 0; 
	padding: 3px 20px;
	font-weight: bold;
	font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
	font-size: 14px;
	line-height: 20px;
}

.calendar table td {
	padding: 3px 6px;
	border: 1px solid #eee;
	background-color: #fff;
	text-align: center;
}

.calendar table td:hover, .timelist li:hover {
	background-color: #f8f8f8;
}

.calendar table th {
	font-weight: bold !important;
}

.calendar-shortcuts {
	text-align: center;
}

.calendar-cancel {
	margin-bottom: 0;
	text-align: center;
}

.calendar-cancel a {
	color: #444;
	font-size: .9em;
}

.calendar-cancel a:hover {
	text-decoration: none;
	color: #666;
}

.timelist {
	list-style: none;
	padding: 0;
	margin: 0;
}

.timelist li {
	background-color: #fff;
	border-bottom: 1px solid #eee;
	padding: 3px;	
}

/* End overriding widget styling */


/* INLINES */

.inline-related h3 {
	margin: 0;
	border: 0;
	border-bottom: 1px solid #d4d4d4;
	padding: 0 10px;
	font-size: 16px;
	color: #fff;
	font-weight: normal;
}

.inline-related h3 a{
	color: #ddd;
	text-decoration: underline;
}

.inline-related h3 a:hover {
	color: #fff;
}

.inline-related {
	border: 1px solid #D4D4D4;
	margin-bottom: 10px;
	-webkit-border-radius: 4px;
	-moz-border-radius: 4px;
	border-radius: 4px;
}

.inline-related span.delete {
	float: right;
	display: inline-block;
}

.empty-form {
	display: none;
}

.tabular.inline-related table {
	margin-bottom: 0;
}

.tabular.inline-related table thead tr {
	border: 0 !important;
}

.tabular.inline-related .add-row td {
	border: 0 !important;
	border-top: 1px solid #eee !important;
}
/* End inlines */