{% load i18n %}<div class="span6 actions clearfix">{% for field in action_form %}{% if field.label %}
									<span class="label label-inverse">{{ field.label }}</span>&#xa0;{% endif %}{{ field }}{% endfor %} 
									<button type="submit" class="btn btn-medium" title="{% trans "Run the selected action" %}" name="index" value="{{ action_index|default:0 }}">{% trans "Go" %}</button>{% if actions_selection_counter %}
									<script>var _actions_icnt="{{ cl.result_list|length|default:"0" }}";</script>
									&#xa0;<span class="action-counter small">{{ selection_note }}</span>{% if cl.result_count != cl.result_list|length %}
									<span class="all">{{ selection_note_all }}</span>
									<span class="question small">
										<a href="#" title="{% trans "Click here to select the objects across all pages" %}">{% blocktrans with cl.result_count as total_count %}Select all {{ total_count }} {{ module_name }}{% endblocktrans %}</a>
									</span>
									<span class="clear small">
										<a href="#">{% trans "Clear selection" %}</a>
									</span>{% endif %}{% endif %}
								</div>
