{% load i18n %}{% if result_hidden_fields %}
								<div class="hiddenfields">{% for item in result_hidden_fields %}
									{{ item }}{% endfor %}
								</div>{% endif %}{% if results %}
								<div class="results">
									<table cellspacing="0" id="result_list" class="table table-bordered table-striped">
										<thead>
											<tr class="navbar-inner">{% for header in result_headers %}
												<th scope="col"{{ header.class_attrib }}>
													<span class="text">{% if header.sortable %}
														<a href="{{ header.url_primary }}">{{ header.text|capfirst }}</a>{% else %}
														{{ header.text|capfirst }}{% endif %}
													</span>{% if header.sortable %}{% if header.sort_priority > 0 %}
													<span class="sortoptions">
														<a class="sortremove" href="{{ header.url_remove }}" title="{% trans "Remove from sorting" %}">
															<i class="icon-remove"></i>
														</a>{% if num_sorted_fields > 1 %}
														<span class="sortpriority" title="{% blocktrans with priority_number=header.sort_priority %}Sorting priority: {{ priority_number }}{% endblocktrans %}">{{ header.sort_priority }}</span>{% endif %}
														<a href="{{ header.url_toggle }}" class="toggle {% if header.ascending %}ascending{% else %}descending{% endif %}" title="{% trans "Toggle sorting" %}">
															<i class="icon-arrow-{% if header.ascending %}down{% else %}up{% endif %}"></i>
														</a>
													</span>{% endif %}{% endif %}
												</th>{% endfor %}
											</tr>
										</thead>
										<tbody>{% for result in results %}{% if result.form.non_field_errors %}
											<tr>
												<td colspan="{{ result|length }}">{{ result.form.non_field_errors }}</td>
											</tr>{% endif %}
											<tr class="{% cycle 'row1' 'row2' %}">{% for item in result %}
												{{ item }}{% endfor %}
											</tr>{% endfor %}
										</tbody>
									</table>
								</div>{% endif %}