{% load admin_list i18n %}
		<p class="paginator grey-degrade">{% if pagination_required %}{% for i in page_range %}
			{% paginator_number cl i %}{% endfor %}{% endif %}
			{{ cl.result_count }} {% ifequal cl.result_count 1 %}{{ cl.opts.verbose_name }}{% else %}{{ cl.opts.verbose_name_plural }}{% endifequal %}{% if show_all_url %}
			&nbsp;&nbsp;<a href="{{ show_all_url }}" class="showall">{% trans 'Show all' %}</a>{% endif %}{% if cl.formset and cl.result_count %}
			<input type="submit" name="_save" class="default" value="{% trans 'Save' %}"/>{% endif %}
		</p>