{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block breadcrumbs %}
		<ul class="breadcrumb">
			<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
			<li class="active">{% trans 'Password reset confirmation' %}</li>
		</ul>{% endblock %}

{% block title %}{% trans 'Password reset' %}{% endblock %}

{% block main-struct %}<div id="content-main">{% if validlink %}
			<header class="page-header">
				<h1>{% trans 'Enter new password' %}</h1>
			</header>
			<p class="alert">{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
			<form action="" method="post">
				{% csrf_token %}
				{{ form.new_password1.errors }}
				<p class="aligned wide"><label for="id_new_password1">{% trans 'New password:' %}</label>{{ form.new_password1 }}</p>
				{{ form.new_password2.errors }}
				<p class="aligned wide"><label for="id_new_password2">{% trans 'Confirm password:' %}</label>{{ form.new_password2 }}</p>
				<p><input type="submit" class="btn btn-success" value="{% trans 'Change my password' %}" /></p>
			</form>{% else %}
			<header class="page-header">
				<h1>{% trans 'Password reset unsuccessful' %}</h1>
			</header>
			<p class="alert alert-error">{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}</p>{% endif %}
		</div>{% endblock %}