{% load i18n %}<fieldset class="module aligned {{ fieldset.classes }}">{% if fieldset.name %}
										<h3>{{ fieldset.name }}</h3>{% endif %}{% if fieldset.description %}
										<div class="alert">{{ fieldset.description|safe }}</div>{% endif %}{% for line in fieldset %}{% if line.fields.0 != 'language' %}
											<div class="row-fluid color-form {% cycle 'row1' 'row2' %}{% if line.fields|length_is:'1' and line.errors %} errors{% endif %}{% for field in line %} {{ field.field.name }}{% endfor %}">
												<div class="field ">{% if not line.fields|length_is:'1' and line.errors %}
													<div class="alert alert-error">
														{{ line.errors }}
													</div>{% endif %}{% for field in line %}
													<div class="control-group {% if not line.fields|length_is:'1' %} field-box{% endif %}{% if not field.is_readonly and field.errors %} error{% endif %}">
														<label class="control-label{% if field.field.required %} required{% endif %}" for="{{field.field.auto_id}}">{{ field.field.label }}:</label>
														<div class="controls">{% if field.is_readonly %}
															<span><i>{{ field.contents }}</i></span>{% elif field.is_checkbox %}
															<span class="switch">
																{{field.field}}
																<span class="switch-track"></span>
																<span class="switch-thumb"></span>
															</span>{% else %}
															{{ field.field }}{% endif %}{% if field.field.help_text %}
															<i class="help icon-question-sign" data-html="true" data-title="{{ field.field.label }} - {% trans 'help text' %}" data-content="{{ field.field.help_text }}"></i>{% endif %}{% if line.fields|length_is:'1' and not field.is_readonly and field.errors %}
															<span class="help-inline">
																{{ field.errors }}
															</span>{% endif %}
														</div>
													</div>{% endfor %}
												</div>
											</div>{% else %}{% for field in line %}
											{{ field.field }}{% endfor %}{% endif %}{% endfor %}
										</fieldset>