{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a></li>
				<li class="active">{% trans 'Password reset' %}</li>
			</ul>{% endblock %}

{% block title %}{% trans 'Password reset complete' %}{% endblock %}

{% block main-struct %}<div id="content-main">
			<header class="page-header">
				<h1>{% trans 'Password reset complete' %}</h1>
			</header>
			<p class="alert alert-success">{% trans "Your password has been set.  You may go ahead and log in now." %}</p>
			<p><a href="{{ login_url }}">{% trans 'Log in' %}</a></p>
		</div>{% endblock %}