{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li class="active">{% trans 'Password reset' %}</li>
			</ul>{% endblock %}

{% block title %}{% trans "Password reset" %}{% endblock %}

{% block main-struct %}<div id="content-main">
			<header class="page-header">
				<h1>{% trans "Password reset" %}</h1>
			</header>
			<p>{% trans "Forgotten your password? Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>
			<form action="" method="post">
				{% csrf_token %}
				{{ form.email.errors }}
				<p><label for="id_email">{% trans 'E-mail address:' %}</label> {{ form.email }}
				<input type="submit" class="btn btn-success" value="{% trans 'Reset my password' %}" /></p>
			</form>
		</div>{% endblock %}