{% extends "admin/base_site.html" %}{% load i18n l10n admin_urls %}{% load url from future %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li><a href="{% url 'admin:app_list' app_label=app_label %}">{{ app_label|capfirst }}</a> <span class="divider">/</span></li>
				<li><a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a> <span class="divider">/</span></li>
				<li class="active">{% trans 'Delete multiple objects' %}</li>
			</ul>{% endblock %}

{% block main-struct %}
			<div class="row-fluid show-grid">{% if perms_lacking or protected %}{% if perms_lacking %}
				<p>{% blocktrans %}Deleting the selected {{ objects_name }} would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktrans %}</p>
				<ul class="delete-list">{% for obj in perms_lacking %}
					<li>{{ obj }}</li>{% endfor %}
				</ul>{% endif %}{% if protected %}
				<p>{% blocktrans %}Deleting the selected {{ objects_name }} would require deleting the following protected related objects:{% endblocktrans %}</p>
				<ul class="delete-list">{% for obj in protected %}
					<li>{{ obj }}</li>{% endfor %}
				</ul>{% endif %}{% else %}
				<p>{% blocktrans %}Are you sure you want to delete the selected {{ objects_name }}? All of the following objects and their related items will be deleted:{% endblocktrans %}</p>{% for deletable_object in deletable_objects %}
				<ul  class="delete-list">
					{{ deletable_object|unordered_list }}
				</ul>{% endfor %}
				<form action="" method="post">
					{% csrf_token %}{% for obj in queryset %}
					<input type="hidden" name="{{ action_checkbox_name }}" value="{{ obj.pk|unlocalize }}" />{% endfor %}
					<input type="hidden" name="action" value="delete_selected" />
					<input type="hidden" name="post" value="yes" />
					<input type="submit" class="btn" value="{% trans "Yes, I'm sure" %}" />
				</form>{% endif %}
			</div>{% endblock %}