{% extends "admin/base_site.html" %}{% load i18n admin_static admin_urls %}{% load url from future %}

{% block extrahead %}{{ block.super }}{% url 'admin:jsi18n' as jsi18nurl %}
		<script type="text/javascript" src="{{ jsi18nurl|default:"../../../../jsi18n/" }}"></script>
		<script src="{% static 'js/yawd-admin.js' %}"></script>{% endblock %}
{% block bodyclass %}{{ opts.app_label }}-{{ opts.object_name.lower }} change-form{% endblock %}

{% block breadcrumbs %}{% if not is_popup %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li><a href="{% url 'admin:app_list' app_label=opts.app_label %}">{{ opts.app_label|capfirst|escape }}</a> <span class="divider">/</span></li>
				<li><a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a> <span class="divider">/</span></li>
				<li><a href="{% url opts|admin_urlname:'changelist' %}{{ original.pk }}/">{{ original|truncatewords:"18" }}</a> <span class="divider">/</span></li>
				<li class="active">{% trans 'Change password' %}</li>
			</ul>{% endif %}{% endblock %}

{% block main-struct %}
			<div class="row-fluid show-grid">
				<div id="content-main" class="span12">
					<form action="{{ form_url }}" method="post" id="{{ opts.module_name }}_form">
						{% csrf_token %}{% block form_top %}{% endblock %}{% if is_popup %}
						<input type="hidden" name="_popup" value="1" />{% endif %}{% if form.errors %}
    					<p class="alert alert-error">
    						{% blocktrans count form.errors.items|length as counter %}Please correct the error below.{% plural %}Please correct the errors below.{% endblocktrans %}
    					</p>{% endif %}
						<p class="alert">
							{% blocktrans with original.username as username %}Enter a new password for the user <strong>{{ username }}</strong>.{% endblocktrans %}
						</p>
						<fieldset class="module aligned">
							<div class="form-row">
								{{ form.password1.errors }}
								<label for="id_password1" class="required">{% trans 'Password' %}:</label> {{ form.password1 }}
							</div>
							<div class="form-row">
								{{ form.password2.errors }}
								<label for="id_password2" class="required">{% trans 'Password (again)' %}:</label> {{ form.password2 }}
  								<i class="help icon-question-sign" data-html="true" data-title="{% trans 'Password (again)' %} - {% trans 'help text' %}" data-content="{% trans 'Enter the same password as above, for verification.' %}"></i>
							</div>
						</fieldset>
						<div class="submit-row">
							<input type="submit" value="{% trans 'Change password' %}" class="btn btn-success" />
						</div>
					</form>
				</div>
			</div>
			<script type="text/javascript">document.getElementById("id_password1").focus();</script>{% endblock %}