{% extends "admin/base_site.html" %}{% load i18n admin_urls %}{% load url from future %}

{% block breadcrumbs %}
		<ul class="breadcrumb">
			<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
			<li><a href="{% url 'admin:app_list' app_label=app_label %}">{{ app_label|capfirst }}</a> <span class="divider">/</span></li>
			<li><a href="{% url opts|admin_urlname:'changelist' %}">{{ module_name }}</a> <span class="divider">/</span></li>
			<li><a href="{% url opts|admin_urlname:'changelist' %}{{ object.pk }}/">{{ object|truncatewords:"18" }}</a> <span class="divider">/</span></li>
			<li class="active">{% trans 'History' %}</li>
		</ul>{% endblock %}

{% block main-struct %}
			<div id="content-main">
				<div class="module">{% if action_list %}
					<table id="change-history" class="table table-bordered table-striped">
						<thead>
							<tr class="navbar-inner">
								<th scope="col">{% trans 'Date/time' %}</th>
								<th scope="col">{% trans 'User' %}</th>
								<th scope="col">{% trans 'Action' %}</th>
							</tr>
						</thead>
						<tbody>{% for action in action_list %}
							<tr>
								<th scope="row">{{ action.action_time|date:"DATETIME_FORMAT" }}</th>
								<td>{{ action.user.username }}{% if action.user.get_full_name %} ({{ action.user.get_full_name }}){% endif %}</td>
								<td>{{ action.change_message }}</td>
							</tr>{% endfor %}
						</tbody>
					</table>{% else %}
					<div class="alert">{% trans "This object doesn't have a change history. It probably wasn't added via this admin site." %}</div>{% endif %}
				</div>
			</div>{% endblock %}