{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block userlinks %}{% url 'django-admindocs-docroot' as docsroot %}
    {% if docsroot %}
    <li><a href="{{ docsroot }}">{% trans 'Documentation' %}</a></li>
    {% endif %}
    <li class="active"><a >{% trans 'Change password' %}</a></li>
    <li><a href="../logout/">{% trans 'Log out' %}</a></li>
{% endblock %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li class="active">{% trans 'Password change' %}</li>
			</ul>{% endblock %}

{% block title %}{% trans 'Password change' %}{% endblock %}

{% block main-struct %}<div id="content-main">
			<header class="page-header">
				<h1>{% trans 'Password change' %}</h1>
			</header>
			<p class="alert alert-success">{% trans 'Your password was changed successfully.' %}</p>
{% endblock %}
