{% if show %}<div class="xfull row-fluid">
									<ul class="toplinks">{% if back %}
										<li class="date-back">
											<a href="{{ back.link }}">&lsaquo; {{ back.title }}</a>
										</li>{% endif %}{% for choice in choices %}
										<li>{% if choice.link %}
											<a href="{{ choice.link }}">{% endif %}{{ choice.title }}{% if choice.link %}</a>{% endif %}
										</li>{% endfor %}
									</ul>
								</div>{% endif %}