{% extends "admin/base_site.html" %}{% load i18n %}{% load url from future %}

{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li class="active">{% trans 'Password reset' %}</li>
			</ul>{% endblock %}

{% block title %}{% trans 'Password reset successful' %}{% endblock %}

{% block main-struct %}<div id="content-main">
			<header class="page-header">
				<h1>{% trans 'Password reset successful' %}</h1>
			</header>
			<p class="alert alert-success">{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>
		</div>{% endblock %}