/* Generated from LESS using BS mixins 

ppetrid:
This is not currently used in the project
but it should be used/modified to allow
for stylish check boxes

*/
.switch {
  display: inline-block;
  width: 75px;
  height: 26px;
  position: relative;
  background-color: #f0f0f0;
  background-image: -moz-linear-gradient(top, #e6e6e6, #ffffff);
  background-image: -ms-linear-gradient(top, #e6e6e6, #ffffff);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#e6e6e6), to(#ffffff));
  background-image: -webkit-linear-gradient(top, #e6e6e6, #ffffff);
  background-image: -o-linear-gradient(top, #e6e6e6, #ffffff);
  background-image: linear-gradient(top, #e6e6e6, #ffffff);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#e6e6e6', endColorstr='#ffffff', GradientType=0);
  border-color: #ffffff #ffffff #d9d9d9;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #ffffff;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

  border: 1px solid #cccccc;
  -webkit-border-radius: 13px;
  -moz-border-radius: 13px;
  border-radius: 13px;
  padding: 0;
  outline: none;
  overflow: hidden;
  cursor: pointer;
}
.switch:hover,
.switch:active,
.switch.active,
.switch.disabled,
.switch[disabled] {
  background-color: #ffffff;
  *background-color: #f2f2f2;
}
.switch:active,
.switch.active {
  background-color: #e6e6e6 \9;
}
.switch > .switch-track {
  display: block;
  width: 13px;
  height: 26px;
  position: absolute;
  z-index: 1;
  border: 0;
  -webkit-border-radius: 13px 0 0 13px;
  -moz-border-radius: 13px 0 0 13px;
  border-radius: 13px 0 0 13px;
  background-color: #0069cc;
  background-image: -moz-linear-gradient(top, #0055cc, #0088cc);
  background-image: -ms-linear-gradient(top, #0055cc, #0088cc);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0055cc), to(#0088cc));
  background-image: -webkit-linear-gradient(top, #0055cc, #0088cc);
  background-image: -o-linear-gradient(top, #0055cc, #0088cc);
  background-image: linear-gradient(top, #0055cc, #0088cc);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#0055cc', endColorstr='#0088cc', GradientType=0);
  border-color: #0088cc #0088cc #005580;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #0088cc;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

  opacity: 0;
  filter: alpha(opacity=0);
  -webkit-transition: width .15s linear, opacity .15s linear;
  -moz-transition: width .15s linear, opacity .15s linear;
  -ms-transition: width .15s linear, opacity .15s linear;
  -o-transition: width .15s linear, opacity .15s linear;
  transition: width .15s linear, opacity .15s linear;
}
.switch > .switch-track:hover,
.switch > .switch-track:active,
.switch > .switch-track.active,
.switch > .switch-track.disabled,
.switch > .switch-track[disabled] {
  background-color: #0088cc;
  *background-color: #0077b3;
}
.switch > .switch-track:active,
.switch > .switch-track.active {
  background-color: #006699 \9;
}
.switch > .switch-track.switch-warning {
  background-color: #f9a123;
  background-image: -moz-linear-gradient(top, #f89406, #fbb450);
  background-image: -ms-linear-gradient(top, #f89406, #fbb450);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f89406), to(#fbb450));
  background-image: -webkit-linear-gradient(top, #f89406, #fbb450);
  background-image: -o-linear-gradient(top, #f89406, #fbb450);
  background-image: linear-gradient(top, #f89406, #fbb450);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#f89406', endColorstr='#fbb450', GradientType=0);
  border-color: #fbb450 #fbb450 #f89406;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #fbb450;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

}
.switch > .switch-track.switch-warning:hover,
.switch > .switch-track.switch-warning:active,
.switch > .switch-track.switch-warning.active,
.switch > .switch-track.switch-warning.disabled,
.switch > .switch-track.switch-warning[disabled] {
  background-color: #fbb450;
  *background-color: #faa937;
}
.switch > .switch-track.switch-warning:active,
.switch > .switch-track.switch-warning.active {
  background-color: #fa9f1e \9;
}
.switch > .switch-track.switch-danger {
  background-color: #d14641;
  background-image: -moz-linear-gradient(top, #bd362f, #ee5f5b);
  background-image: -ms-linear-gradient(top, #bd362f, #ee5f5b);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#bd362f), to(#ee5f5b));
  background-image: -webkit-linear-gradient(top, #bd362f, #ee5f5b);
  background-image: -o-linear-gradient(top, #bd362f, #ee5f5b);
  background-image: linear-gradient(top, #bd362f, #ee5f5b);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#bd362f', endColorstr='#ee5f5b', GradientType=0);
  border-color: #ee5f5b #ee5f5b #e51d18;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #ee5f5b;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

}
.switch > .switch-track.switch-danger:hover,
.switch > .switch-track.switch-danger:active,
.switch > .switch-track.switch-danger.active,
.switch > .switch-track.switch-danger.disabled,
.switch > .switch-track.switch-danger[disabled] {
  background-color: #ee5f5b;
  *background-color: #ec4844;
}
.switch > .switch-track.switch-danger:active,
.switch > .switch-track.switch-danger.active {
  background-color: #e9322d \9;
}
.switch > .switch-track.switch-success {
  background-color: #58b058;
  background-image: -moz-linear-gradient(top, #51a351, #62c462);
  background-image: -ms-linear-gradient(top, #51a351, #62c462);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#51a351), to(#62c462));
  background-image: -webkit-linear-gradient(top, #51a351, #62c462);
  background-image: -o-linear-gradient(top, #51a351, #62c462);
  background-image: linear-gradient(top, #51a351, #62c462);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#51a351', endColorstr='#62c462', GradientType=0);
  border-color: #62c462 #62c462 #3b9e3b;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #62c462;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

}
.switch > .switch-track.switch-success:hover,
.switch > .switch-track.switch-success:active,
.switch > .switch-track.switch-success.active,
.switch > .switch-track.switch-success.disabled,
.switch > .switch-track.switch-success[disabled] {
  background-color: #62c462;
  *background-color: #4fbd4f;
}
.switch > .switch-track.switch-success:active,
.switch > .switch-track.switch-success.active {
  background-color: #42b142 \9;
}
.switch > .switch-track.switch-info {
  background-color: #41a7c5;
  background-image: -moz-linear-gradient(top, #2f96b4, #5bc0de);
  background-image: -ms-linear-gradient(top, #2f96b4, #5bc0de);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#2f96b4), to(#5bc0de));
  background-image: -webkit-linear-gradient(top, #2f96b4, #5bc0de);
  background-image: -o-linear-gradient(top, #2f96b4, #5bc0de);
  background-image: linear-gradient(top, #2f96b4, #5bc0de);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#2f96b4', endColorstr='#5bc0de', GradientType=0);
  border-color: #5bc0de #5bc0de #28a1c5;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #5bc0de;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

}
.switch > .switch-track.switch-info:hover,
.switch > .switch-track.switch-info:active,
.switch > .switch-track.switch-info.active,
.switch > .switch-track.switch-info.disabled,
.switch > .switch-track.switch-info[disabled] {
  background-color: #5bc0de;
  *background-color: #46b8da;
}
.switch > .switch-track.switch-info:active,
.switch > .switch-track.switch-info.active {
  background-color: #31b0d5 \9;
}
.switch > .switch-track.switch-inverse {
  background-color: #363636;
  background-image: -moz-linear-gradient(top, #222222, #555555);
  background-image: -ms-linear-gradient(top, #222222, #555555);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#222222), to(#555555));
  background-image: -webkit-linear-gradient(top, #222222, #555555);
  background-image: -o-linear-gradient(top, #222222, #555555);
  background-image: linear-gradient(top, #222222, #555555);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#222222', endColorstr='#555555', GradientType=0);
  border-color: #555555 #555555 #2f2f2f;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #555555;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

}
.switch > .switch-track.switch-inverse:hover,
.switch > .switch-track.switch-inverse:active,
.switch > .switch-track.switch-inverse.active,
.switch > .switch-track.switch-inverse.disabled,
.switch > .switch-track.switch-inverse[disabled] {
  background-color: #555555;
  *background-color: #484848;
}
.switch > .switch-track.switch-inverse:active,
.switch > .switch-track.switch-inverse.active {
  background-color: #3b3b3b \9;
}
.switch > .switch-thumb {
  display: block;
  width: 24px;
  height: 24px;
  position: absolute;
  z-index: 3;
  top: 0;
  background-color: #f5f5f5;
  background-image: -moz-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -ms-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#ffffff), to(#e6e6e6));
  background-image: -webkit-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: -o-linear-gradient(top, #ffffff, #e6e6e6);
  background-image: linear-gradient(top, #ffffff, #e6e6e6);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffff', endColorstr='#e6e6e6', GradientType=0);
  border-color: #e6e6e6 #e6e6e6 #bfbfbf;
  border-color: rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.1) rgba(0, 0, 0, 0.25);
  filter: progid:DXImageTransform.Microsoft.gradient(enabled = false);
  *background-color: #e6e6e6;
  /* Darken IE7 buttons by default so they stand out more given they won't have borders */

  border: 1px solid #999999;
  -webkit-border-radius: 13px;
  -moz-border-radius: 13px;
  border-radius: 13px;
  -webkit-transition: left 0.15s linear;
  -moz-transition: left 0.15s linear;
  -ms-transition: left 0.15s linear;
  -o-transition: left 0.15s linear;
  transition: left 0.15s linear;
}
.switch > .switch-thumb:hover,
.switch > .switch-thumb:active,
.switch > .switch-thumb.active,
.switch > .switch-thumb.disabled,
.switch > .switch-thumb[disabled] {
  background-color: #e6e6e6;
  *background-color: #d9d9d9;
}
.switch > .switch-thumb:active,
.switch > .switch-thumb.active {
  background-color: #cccccc \9;
}
.switch > .switch-thumb:hover {
  background-position: 0 -15px;
  -webkit-transition: left .15s linear, background-position .1s linear;
  -moz-transition: left .15s linear, background-position .1s linear;
  -ms-transition: left .15s linear, background-position .1s linear;
  -o-transition: left .15s linear, background-position .1s linear;
  transition: left .15s linear, background-position .1s linear;
}
.switch > .switch-thumb:before,
.switch > .switch-thumb:after {
  display: block;
  width: 61px;
  height: 24px;
  position: absolute;
  z-index: -1;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  font-weight: bold;
  line-height: 24px;
  text-shadow: 0 1px 1px rgba(0, 0, 0, 0.25);
  text-align: center;
}
.switch > .switch-thumb:before {
  content: "ON";
  left: -50px;
  text-indent: -6px;
  color: #ffffff;
}
.switch > .switch-thumb[data-label-on]:before {
  content: attr(data-label-on);
}
.switch > .switch-thumb:after {
  content: "OFF";
  left: 11px;
  text-indent: 6px;
  color: #555555;
}
.switch > .switch-thumb[data-label-off]:after {
  content: attr(data-label-off);
}
.switch > input[type="checkbox"] {
  display: none;
}
.switch > input[type="checkbox"]:checked ~ .switch-track {
  opacity: 1;
  filter: alpha(opacity=100);
  width: 61px;
}

.switch > input[type="checkbox"]:checked ~ .switch-thumb {
  left: 49px;
}