{% extends "admin/change_form.html" %}{% load i18n %}

{% block form_top %}{% if not is_popup %}
					<p class="alert">{% trans "First, enter a username and password. Then, you'll be able to edit more user options." %}</p>{% else %}
					<p class="alert">{% trans "Enter a username and password." %}</p>{% endif %}{% endblock %}