{% extends "admin/base_site.html" %}{% load i18n yawdadmin_filters %}{% load url from future %}

{% if not is_popup %}{% block breadcrumbs %}
			<ul class="breadcrumb">
				<li><a href="{% url 'admin:index' %}"><i class="icon-home"></i></a> <span class="divider">/</span></li>
				<li class="active">{% for app in app_list %}{% blocktrans with app.name|app_title as name %}{{ name }}{% endblocktrans %}{% endfor %}</li>
			</ul>{% endblock %}{% endif %}

{% block main-struct %}
			<div id="content-main">{% if app_list %}{% for app in app_list %}
				<table class="table table-rounded table-striped" summary="{% blocktrans with app.name as name %}Models available in the {{ name }} application.{% endblocktrans %}">
					<thead>
						<tr class="navbar-inner">
							<th colspan="2" class="title"><a href="{{ app.app_url }}" class="section">{% blocktrans with app.name as name %}{{ name }}{% endblocktrans %}</a></th>
						</tr>
					</thead>
					<tbody>{% for model in app.models %}
						<tr>{% if model.perms.change %}
							<td><a href="{{ model.admin_url }}">{{ model.name }}</a></td>{% else %}
							<td>{{ model.name }}</td>{% endif %}
							<td>
								<div class="pull-right">{% if model.perms.add %}
									<a href="{{ model.admin_url }}add/" class="btn btn-mini btn-success">
										<i class="icon-plus icon-white"></i>&#xa0;{% trans 'Add' %}
									</a>{% endif %}{% if model.perms.change %}
									<a href="{{ model.admin_url }}" class="btn btn-mini btn-info">
										{% trans 'Change' %}&#xa0;<i class="icon-edit icon-white"></i>
									</a>{% endif %}
								</div>
							</td>
						</tr>{% endfor %}
					</tbody>
				</table>{% endfor %}{% else %}
				<p class="alert">{% trans "You don't have permission to edit anything." %}</p>{% endif %}
			</div>{% endblock %}